@@ -19,6 +19,7 @@ import Control.Monad
 import Control.Exception (try, SomeException)
 import Test.Hspec
 import Data.Either.Compat
+import System.Directory (createDirectory, createDirectoryIfMissing)
 import Test.Mockery.Directory
 
 import qualified Data.Yaml as D
@@ -33,6 +34,8 @@ import Data.Vector (Vector)
 import qualified Data.Vector as V
 import Data.HashMap.Strict (HashMap)
 import qualified Data.HashMap.Strict as HM
+import System.IO (hClose)
+import System.IO.Temp (withSystemTempFile)
 
 data TestJSON = TestJSON
               { string :: Text
@@ -63,6 +66,7 @@ spec = do
     describe "Data.Yaml" $ do
         it "encode/decode" caseEncodeDecodeData
         it "encode/decode file" caseEncodeDecodeFileData
+        it "encode/decode files with non-ASCII names" caseEncodeDecodeNonAsciiFileData
         it "encode/decode strings" caseEncodeDecodeStrings
         it "decode invalid file" caseDecodeInvalid
         it "processes datatypes" caseDataTypes
@@ -150,6 +154,8 @@ spec = do
 
     it "preserves Scientific precision" casePreservesScientificPrecision
 
+    it "truncates files" caseTruncatesFiles
+
 
 specialStrings :: [T.Text]
 specialStrings =
@@ -317,6 +323,22 @@ caseEncodeDecodeFileData = withFile "" $ \fp -> do
     out <- D.decodeFile fp
     out @?= Just sample
 
+caseEncodeDecodeNonAsciiFileData :: Assertion
+caseEncodeDecodeNonAsciiFileData = do
+  let mySample = (object ["foo" .= True])
+  inTempDirectory $ do
+    createDirectory "accenté"
+    D.encodeFile "accenté/bar.yaml" mySample
+    out1 <- D.decodeFile "accenté/bar.yaml"
+    out1 @?= Just mySample
+
+  createDirectoryIfMissing True "test/resources/accenté/"
+
+  readFile "test/resources/accent/foo.yaml" >>=
+    writeFile "test/resources/accenté/foo.yaml"
+  out2 <- D.decodeFile "test/resources/accenté/foo.yaml"
+  out2 @?= Just mySample
+
 caseEncodeDecodeStrings :: Assertion
 caseEncodeDecodeStrings = do
     let out = D.decode $ D.encode sample
@@ -484,3 +506,12 @@ casePreservesScientificPrecision = do
     -- results, because of <https://github.com/bos/text/issues/34>.
     D.decodeEither "x: 9.78159610558926e-5" @?= Right (object
         [ "x" .= D.Number (read "9.78159610558926e-5") ])
+
+caseTruncatesFiles :: Assertion
+caseTruncatesFiles = withSystemTempFile "truncate.yaml" $ \fp h -> do
+    replicateM_ 500 $ B8.hPut h "HELLO WORLD!!!!!\n"
+    hClose h
+    let val = object ["hello" .= ("world" :: String)]
+    D.encodeFile fp val
+    res <- D.decodeFileEither fp
+    either (Left . show) Right res `shouldBe` Right val
